Package: sjstats
Type: Package
Encoding: UTF-8
Title: Collection of Convenient Functions for Common Statistical
        Computations
Version: 0.19.0
Authors@R: person("Daniel", "Lüdecke", role = c("aut", "cre"), email = "d.luedecke@uke.de", comment = c(ORCID = "0000-0002-8895-3206"))
Maintainer: Daniel Lüdecke <d.luedecke@uke.de>
Description: Collection of convenient functions for common statistical computations,
             which are not directly provided by R's base or stats packages.
             This package aims at providing, first, shortcuts for statistical measures, 
             which otherwise could only be calculated with additional effort 
             (like Cramer's V, Phi, or effect size statistics like Eta or Omega squared), 
             or for which currently no functions available. Second, another focus 
             lies on weighted variants of common statistical measures and tests 
             like weighted standard error, mean, t-test, correlation, and more.
License: GPL-3
Depends: R (>= 3.4), utils
Imports: datawizard, effectsize (>= 0.8.8), insight, parameters,
        performance, stats
Suggests: brms, car, coin, ggplot2, lme4, MASS, pscl, pwr, survey,
        testthat
URL: https://strengejacke.github.io/sjstats/
BugReports: https://github.com/strengejacke/sjstats/issues
RoxygenNote: 7.3.1
Config/testthat/edition: 3
Config/testthat/parallel: true
NeedsCompilation: no
Packaged: 2024-05-14 08:43:22 UTC; Daniel
Author: Daniel Lüdecke [aut, cre] (<https://orcid.org/0000-0002-8895-3206>)
Repository: CRAN
Date/Publication: 2024-05-14 09:10:02 UTC
Built: R 4.4.0; ; 2024-05-16 06:07:25 UTC; unix
