# Generated by roxygen2: do not edit by hand

S3method(AIC,svyglm.nb)
S3method(as.data.frame,sj_resample)
S3method(as.integer,sj_resample)
S3method(cramers_v,formula)
S3method(cramers_v,ftable)
S3method(cramers_v,table)
S3method(deviance,svyglm.nb)
S3method(family,svyglm.nb)
S3method(formula,svyglm.nb)
S3method(formula,svyglm.zip)
S3method(model.frame,svyglm.nb)
S3method(model.frame,svyglm.zip)
S3method(phi,formula)
S3method(phi,ftable)
S3method(phi,table)
S3method(plot,sj_inequ_trend)
S3method(predict,svyglm.nb)
S3method(print,sj_anova_stat)
S3method(print,sj_chi2gof)
S3method(print,sj_htest_chi)
S3method(print,sj_htest_kw)
S3method(print,sj_htest_mwu)
S3method(print,sj_htest_t)
S3method(print,sj_htest_wilcox)
S3method(print,sj_resample)
S3method(print,sj_ttest)
S3method(print,sj_wcor)
S3method(print,sj_xtab_stat)
S3method(print,svyglm.nb)
S3method(print,svyglm.zip)
S3method(residuals,svyglm.nb)
S3method(terms,svyglm.nb)
S3method(weighted_correlation,default)
S3method(weighted_correlation,formula)
S3method(weighted_se,data.frame)
S3method(weighted_se,default)
S3method(weighted_se,matrix)
export(anova_stats)
export(auto_prior)
export(boot_ci)
export(boot_est)
export(boot_p)
export(boot_se)
export(bootstrap)
export(chi_squared_test)
export(chisq_gof)
export(cohens_f)
export(cramer)
export(cramers_v)
export(crosstable_statistics)
export(cv)
export(cv_compare)
export(cv_error)
export(design_effect)
export(epsilon_sq)
export(eta_sq)
export(find_beta)
export(find_beta2)
export(find_cauchy)
export(find_normal)
export(gmd)
export(icc)
export(inequ_trend)
export(is_prime)
export(kruskal_wallis_test)
export(link_inverse)
export(mann_whitney_test)
export(mean_n)
export(means_by_group)
export(mse)
export(omega_sq)
export(p_value)
export(phi)
export(prop)
export(props)
export(r2)
export(rmse)
export(robust)
export(samplesize_mixed)
export(scale_weights)
export(sd_pop)
export(se)
export(se_ybar)
export(smpsize_lmm)
export(survey_median)
export(svyglm.nb)
export(svyglm.zip)
export(t_test)
export(table_values)
export(var_pop)
export(weight)
export(weight2)
export(weighted_correlation)
export(weighted_mean)
export(weighted_median)
export(weighted_sd)
export(weighted_se)
export(wilcoxon_test)
export(xtab_statistics)
importFrom(datawizard,weighted_mean)
importFrom(datawizard,weighted_median)
importFrom(datawizard,weighted_sd)
importFrom(insight,link_inverse)
importFrom(performance,mse)
importFrom(performance,rmse)
importFrom(stats,family)
