# kruskal_wallis_test

    Code
      print(out1)
    Output
      # Kruskal-Wallis test
      
        Data: e17age by c172code (3 groups, n = 506, 180 and 156)
      
        χ² = 4.05, df = 2, p = 0.132
      

---

    Code
      print(out1)
    Output
      # Kruskal-Wallis test
      
        Data: scale1 by scale2 (3 groups, n = 20, 20 and 20)
      
        χ² = 4.86, df = 2, p = 0.088
      

