# wilcoxon_test

    Code
      print(out1)
    Output
      # One Sample Wilcoxon signed rank test
      
        Alternative hypothesis: true location shift is not equal to 0
      
        V = 528, p < .001
      

---

    Code
      print(out1)
    Output
      # Paired Wilcoxon signed rank test
      
        Alternative hypothesis: true location shift is not equal to 0
      
        V = 0, r = 0.87, Z = -4.94, p < .001
      

---

    Code
      print(out)
    Output
      # Paired Wilcoxon signed rank test
      
        Alternative hypothesis: true location shift is not equal to 0
      
        V = 247, r = 0.39, Z = -2.76, p = 0.006
      

