# chi_squared_test

    Code
      print(out1)
    Output
      
      # Chi-squared test for contingency tables
      
        Data: c161sex by e16sex (n = 900)
      
        χ² = 2.233, ϕ = 0.053 (very small effect), df = 1, p = 0.135
      

---

    Code
      print(out)
    Output
      
      # Chi-squared test for contingency tables (weighted)
      
        Data: c161sex by e16sex (n = 904)
      
        χ² = 2.416, ϕ = 0.054 (very small effect), df = 1, p = 0.120
      

---

    Code
      print(out1)
    Output
      
      # Chi-squared test for given probabilities
      
        Data: c161sex against probabilities 30% and 70% (n = 901)
      
        χ² = 16.162, פ‎ = 0.088 (very small effect), df = 1, p < .001
      

---

    Code
      print(out)
    Output
      
      # Chi-squared test for given probabilities (weighted)
      
        Data: c161sex against probabilities 30% and 70% (n = 906)
      
        χ² = 20.074, פ‎ = 0.097 (very small effect), df = 1, p < .001
      

---

    Code
      print(out1)
    Output
      
      # Chi-squared test for contingency tables
        (using McNemar's test for paired data)
      
        Data: survey_1 by survey_2 (n = 1000)
      
        χ² = 10.868, ϕ = 0.032 (tiny effect), df = 1, p < .001
      

