# mann_whitney_test

    Code
      print(out1)
    Output
      # Mann-Whitney test
      
        Group 1: male   (n = 294, rank mean = 147.50)
        Group 2: female (n = 596, rank mean = 298.50)
        Alternative hypothesis: true location shift is not equal to 0
      
        W = 59684 , r = 0.26, Z = -7.75, p < .001
      

---

    Code
      print(out1)
    Output
      # Mann-Whitney test
      
        Group 1: scale1 (n = 20, rank mean = 10.50)
        Group 2: scale2 (n = 20, rank mean = 10.50)
        Alternative hypothesis: true location shift is not equal to 0
      
        W = 188 , r = 0.05, Z = -0.32, p = 0.758
      

---

    Code
      print(out)
    Output
      # Mann-Whitney test (weighted)
      
        Group 1: male   (n = 296, rank mean = 147.58)
        Group 2: female (n = 600, rank mean = 299.42)
      
        r = 0.26, Z = 7.78, p < .001
      

